@@ -10,8 +10,11 @@
 //! Procedural macros for use with Ockam.
 
 use proc_macro::TokenStream;
+use quote::quote;
+use syn::{parse_macro_input, AttributeArgs, DeriveInput, ItemFn};
 
 mod async_try_clone_derive;
+mod internals;
 mod message_derive;
 mod node_attribute;
 mod node_test_attribute;
@@ -30,7 +33,10 @@ mod vault_test_sync_attribute;
 /// ```
 #[proc_macro_derive(AsyncTryClone)]
 pub fn async_try_clone_derive(input: TokenStream) -> TokenStream {
-    async_try_clone_derive::entry(input)
+    let input = parse_macro_input!(input as DeriveInput);
+    async_try_clone_derive::expand(input)
+        .unwrap_or_else(to_compile_errors)
+        .into()
 }
 
 /// Implements Message trait for a type.
@@ -45,7 +51,8 @@ pub fn async_try_clone_derive(input: TokenStream) -> TokenStream {
 /// ```
 #[proc_macro_derive(Message)]
 pub fn message_derive(input: TokenStream) -> TokenStream {
-    message_derive::entry(input)
+    let input = parse_macro_input!(input as DeriveInput);
+    message_derive::expand(input).unwrap_or_else(to_compile_error)
 }
 
 /// Marks an async function to be run in an ockam node.
@@ -69,7 +76,11 @@ pub fn message_derive(input: TokenStream) -> TokenStream {
 /// ```
 #[proc_macro_attribute]
 pub fn node(args: TokenStream, item: TokenStream) -> TokenStream {
-    node_attribute::entry(args, item)
+    let input_fn = syn::parse_macro_input!(item as ItemFn);
+    let attrs = syn::parse_macro_input!(args as AttributeArgs);
+    node_attribute::expand(input_fn, attrs)
+        .unwrap_or_else(to_compile_errors)
+        .into()
 }
 
 /// Marks an async test function to be run in an ockam node.
@@ -95,7 +106,11 @@ pub fn node(args: TokenStream, item: TokenStream) -> TokenStream {
 /// ```
 #[proc_macro_attribute]
 pub fn test(args: TokenStream, item: TokenStream) -> TokenStream {
-    node_test_attribute::entry(args, item)
+    let input_fn = syn::parse_macro_input!(item as ItemFn);
+    let attrs = syn::parse_macro_input!(args as AttributeArgs);
+    node_test_attribute::expand(input_fn, attrs)
+        .unwrap_or_else(to_compile_errors)
+        .into()
 }
 
 /// Expands to a test suite for a custom implementation of the vault traits.
@@ -116,7 +131,8 @@ pub fn test(args: TokenStream, item: TokenStream) -> TokenStream {
 /// ```
 #[proc_macro_attribute]
 pub fn vault_test(_attr: TokenStream, item: TokenStream) -> TokenStream {
-    vault_test_attribute::entry(_attr, item)
+    let input_fn = parse_macro_input!(item as ItemFn);
+    vault_test_attribute::expand(input_fn).unwrap_or_else(to_compile_error)
 }
 
 /// Expands to a test suite for a custom implementation of the vault traits.
@@ -137,5 +153,15 @@ pub fn vault_test(_attr: TokenStream, item: TokenStream) -> TokenStream {
 /// ```
 #[proc_macro_attribute]
 pub fn vault_test_sync(_attr: TokenStream, item: TokenStream) -> TokenStream {
-    vault_test_sync_attribute::entry(_attr, item)
+    let input_fn = parse_macro_input!(item as ItemFn);
+    vault_test_sync_attribute::expand(input_fn).unwrap_or_else(to_compile_error)
+}
+
+fn to_compile_errors(errors: Vec<syn::Error>) -> proc_macro2::TokenStream {
+    let compile_errors = errors.iter().map(syn::Error::to_compile_error);
+    quote!(#(#compile_errors)*)
+}
+
+fn to_compile_error(error: syn::Error) -> TokenStream {
+    error.to_compile_error().into()
 }
